@@ -1,10 +1,9 @@
 use f32 as dp; // dimension
 use crate::cprelude;
-use fast_inv_sqrt::InvSqrt32;
 
 pub struct Point {
-    x: dp,
-    y: dp
+    pub x: dp,
+    pub y: dp
 }
 fn square_dp(n: dp) -> dp {
     n.powf(2.0)
@@ -15,7 +14,7 @@ impl Point {
         let delta_y = other.y - self.y;
 
         (square_dp(delta_x) + square_dp(delta_y))
-            .inv_sqrt32()
+            .sqrt()
     }
 }
 impl cprelude::CloseEnough for Point {
